@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Object::Pad::FieldAttr::Checked 0.02;
+package Object::Pad::FieldAttr::Checked 0.03;
 
 use v5.14;
 use warnings;
@@ -45,8 +45,8 @@ Or, standalone:
    }
 
    class Point {
-      field $x :param :reader :Checked(Numerical);
-      field $y :param :reader :Checked(Numerical);
+      field $x :param :reader :Checked('Numerical');
+      field $y :param :reader :Checked('Numerical');
    }
 
    ...
@@ -55,19 +55,19 @@ Or, standalone:
 
 This module provides a third-party field attribute for L<Object::Pad>-based
 classes, which declares that values assigned to the field must conform to a
-given value constraint check.
+given constraint check.
 
 B<WARNING> The ability for L<Object::Pad> to take third-party field attributes
 is still new and highly experimental, and subject to much API change in
 future. As a result, this module should be considered equally experimental.
 
 Additionally, the behaviour provided by this module should be considered more
-of a work-in-progress stepping stone. Ideally, value constraint syntax ought
-to be provided in a much more fundamental way by native Perl syntax, allowing
-it to be used on C<my> lexicals, subroutine parameters, and other places as
-well as object fields. This module is more of a placeholder to allow some part
-of that behaviour to be specified for object fields, while not getting in the
-way of a more general, more powerful system being added in future.
+of a work-in-progress stepping stone. Ideally, constraint syntax ought
+to be provided in a much more fundamental way by Perl itself, allowing it to
+be used on C<my> lexicals, subroutine parameters, and other places as well as
+object fields. This module is more of a placeholder to allow some part of that
+behaviour to be specified for object fields, while not getting in the way of a
+more general, more powerful system being added in future.
 
 =head1 FIELD ATTRIBUTES
 
@@ -81,13 +81,19 @@ non-conforming value will throw an exception and the field will not be
 modified.
 
 At compiletime, the string given by I<EXPRESSION> is C<eval()>'ed in scalar
-context, and its result is stored as part of the field's definition. The value
-of the expression must either be an object reference, or a string containing
-the name of a package. In either case, a method called C<check> must exist on
-it.
+context, and its result is stored as part of the field's definition. The
+expression must yield either an object reference, or a string containing the
+name of a package. In either case, a method called C<check> must exist on it.
 
-At runtime, this constraint checking value is used every time an attempt is
-made to assign a new value to the field, whether that is from C<:param>
+During the string C<eval()> of the expression, the C<strict 'subs'> pragma is
+specifically disabled, allowing a bareword to be used as the name of a
+package. This feature may be removed in future, so be sure to quote package
+names if required.
+
+   field $x :Checked('CheckerPackage');
+
+At runtime, this constraint checker is used every time an attempt is made to
+assign a new value to the field, whether that is from C<:param>
 initialisation, invoking a C<:writer> or C<:mutator> accessor, or direct
 assignment into the field variable by method code within the class. The
 checker is used as the invocant for invoking a C<check> method, and the new
@@ -107,9 +113,9 @@ object provided by that module is already supported here.
 
 (For performance reasons, the C<check> method is actually resolved into a
 function at compiletime when the C<:Checked> attribute is applied, and this
-stored value is the one that is called at assignment time. If the method
+stored function is the one that is called at assignment time. If the method
 itself is replaced later by globref assignment or other trickery, this updated
-value will not be used.)
+function will not be used.)
 
 =cut
 
